#!/bin/bash
#********************************************************************************
# qrtools postsync hook                                                         *
#                                                                               *
#  Author: Kai Peter, ©2016-                                                    *
# Version: 0.1                                                                  *
# License: ISC                                                                  *
#********************************************************************************
CFGFILE="/etc/portage/qrtools.conf/postsync.conf"

LOG=/tmp/qrtools.postsync.log
echo "PORTDIR: ${REPOPATH}" >> "$LOG"

PORTDIR=/var/portage/gentoo

# The next variables comes from protage:
REPONAME=${1}		# The repository name
sync_uri=${2}		# The URI to which the repository was synced
REPOPATH=${3}		# The path to the repository

function getEbuildName () { PKG=`echo "$L" | cut -d: -f2` ; }

function Result () {
  C=`tput cols` ; C=$(($C-4))
  printf "\033[${C}G"
  case "$EC" in
	"0") printf "\033[32m%s\033[0m\n" "OK";;
	"X") printf "\033[33m%s\033[0m\n" "--" ;;
	  *) printf "\033[1m\033[91m%s\033[0m\n" "!!";;
  esac
}
#
function doRename () {
  getEbuildName
  echo -n "Renaming package: $PKG "
  if [ -d "${REPOPATH}/${PKG}" ] ; then
	mv "${REPOPATH}/${PKG}" "${REPOPATH}/${PKG}-qrt" ; EC=$?
   else EC="X" ; fi
  Result

}
#
function doDelete () {
  getEbuildName
  echo -n "Deleting package: $PKG"
  if [ -d "${REPOPATH}/${PKG}" ] ; then
    rm -rf "${REPOPATH}/${PKG}" "${REPOPATH}/${PKG}-qrt"
   else 
       EC="X"
  fi
  Result
}
#
function doPatch () {
  getEbuildName
  local EBUILD
#echo 0: $PKG
  # first we check if a patch exists overall
  FLDR=`echo "$PKG" | cut -d\/ -f2`		# the package ebuild folder
  PATCH="/mnt/NAS/Projects/Gentoo R tools/$FLDR.patch"

  [ -f "$PATCH" ] || return #&& echo found || echo "not found"
  
  echo -n "Patching package: $PKG"
#echo
  # get the latest not masked ebuild version and get the correct line
  EBUILD=`emerge -pv --nodeps "$PKG" | grep ^'\[ebuild' | grep "$PKG"` \
	2>&1>/dev/null		# ... suppress any output from grep
  # split the line: two steps to get the ebuild name w/o the path
  EBUILD=`echo "$EBUILD" | cut -d\] -f2 | awk '{ print \$1; }'`
  EBUILD=`echo "$EBUILD" | cut -d\: -f1 | cut -d\/ -f2`
#echo 2: "$EBUILD"
  # now we put all together with the absolute path
  EBUILD="${REPOPATH}/${PKG}/${EBUILD}.ebuild"
#echo 4: EBUILD: $EBUILD

  patch --dry-run "${EBUILD}" < "$PATCH" 2>&1>/dev/null && \
  patch -f "${EBUILD}" < "$PATCH" 2>&1>/dev/null
  EC=$?
  # the patch could fail because it was applied already --> TODO
#  if [ "$EC" != "0" ] ; then
#	[ -f "${EBUILD}.orig" ] && echo " - done already"
#  fi

  EC=$? ; Result


  if [ "$EC" = "0" ] ; then
	( pushd "${REPOPATH}/${PKG}" 
	  repoman manifest
	  popd ) 2>&1>/dev/null
  fi
#  Result #0 || Result 1  #echo failed

}

function ReadConfigFile () {
  while IFS= read L ; do
	ACTION=`echo "$L" | cut -d: -f1`
	case "$ACTION" in
	  D) doDelete;;
	  R) doRename;;
	  P) doPatch;;
	esac
	PKG=""
  done < "$CFGFILE"
}

echo REPONAME: ${REPONAME}  >> "$LOG"
echo REPOPATH: ${REPOPATH}  >> "$LOG"
echo sync_uri: ${2}  >> "$LOG"

REPONAME=gentoo
REPOPATH="$PORTDIR"
if [ "${REPONAME}" = "gentoo" ] ; then
  #
  [ -f "$CFGFILE" ] && ReadConfigFile

#echo
#echo "Renaming mailx repo ..."  #>> "$LOG"
#echo
#  mv ${PORTDIR}/mail-client/mailx ${PORTDIR}/mail-client/mailx-qrt

fi
